@@ -19,13 +19,20 @@
 #include "iassistant.h"
 #include <kaction.h>
 #include <QMetaType>
+#include <QTextEdit>
 
 using namespace KDevelop;
 
 Q_DECLARE_METATYPE(KSharedPtr<IAssistantAction>)
 
+// Very slow and ugly, but very secure
+static QString removeHtmlFromString(QString string)
+{
+    return QTextEdit(string).toPlainText();
+}
+
 KAction* KDevelop::IAssistantAction::toKAction() const {
-    KAction* ret = new KAction(KIcon(icon()), description(), 0);
+    KAction* ret = new KAction(KIcon(icon()), removeHtmlFromString(description()), 0);
     ret->setToolTip(toolTip());
     qRegisterMetaType<KSharedPtr<IAssistantAction> >("KSharedPtr<IAssistantAction>()");
     
