@@ -108,27 +108,32 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     connect( d->m_buildAll, SIGNAL(triggered()), this, SLOT(buildAllProjects()) );
     actionCollection()->addAction( "project_buildall", d->m_buildAll );
     d->m_build = new KAction( i18n("Build Selection"), this );
+    d->m_build->setIconText( i18n("Build") );
     d->m_build->setShortcut( Qt::Key_F8 );
     d->m_build->setIcon(KIcon("run-build"));
     d->m_build->setEnabled( false );
     connect( d->m_build, SIGNAL(triggered()), this, SLOT(buildProjectItems()) );
     actionCollection()->addAction( "project_build", d->m_build );
     d->m_install = new KAction( i18n("Install Selection"), this );
+    d->m_install->setIconText( i18n("Install") );
     d->m_install->setIcon(KIcon("run-build-install"));
     d->m_install->setEnabled( false );
     connect( d->m_install, SIGNAL(triggered()), this, SLOT(installProjectItems()) );
     actionCollection()->addAction( "project_install", d->m_install );
     d->m_clean = new KAction( i18n("Clean Selection"), this );
+    d->m_clean->setIconText( i18n("Clean") );
     d->m_clean->setIcon(KIcon("run-build-clean"));
     d->m_clean->setEnabled( false );
     connect( d->m_clean, SIGNAL(triggered()), this, SLOT(cleanProjectItems()) );
     actionCollection()->addAction( "project_clean", d->m_clean );
     d->m_configure = new KAction( i18n("Configure Selection"), this );
+    d->m_configure->setIconText( i18n("Configure") );
     d->m_configure->setIcon(KIcon("run-build-configure"));
     d->m_configure->setEnabled( false );
     connect( d->m_configure, SIGNAL(triggered()), this, SLOT(configureProjectItems()) );
     actionCollection()->addAction( "project_configure", d->m_configure );
     d->m_prune = new KAction( i18n("Prune Selection"), this );
+    d->m_prune->setIconText( i18n("Prune") );
     d->m_prune->setIcon(KIcon("run-build-prune"));
     d->m_prune->setEnabled( false );
     connect( d->m_prune, SIGNAL(triggered()), this, SLOT(pruneProjectItems()) );
@@ -142,9 +147,9 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     core()->uiController()->addToolView( i18n("Projects"), d->factory );
     connect( core()->selectionController(), SIGNAL(selectionChanged(KDevelop::Context*)),
              SLOT(updateActionState(KDevelop::Context*)));
-    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsInserted(const QModelIndex&, int, int)),
+    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
              SLOT(updateFromBuildSetChange()));
-    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
+    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
              SLOT(updateFromBuildSetChange()));
     connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(modelReset()),
              SLOT(updateFromBuildSetChange()));
@@ -200,6 +205,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
     bool needsBuildItems = true;
     bool needsFolderItems = true;
     bool needsRemoveAndRename = true;
+    bool needsRemoveTargetFiles = true;
 
     //needsCreateFile if there is one item and it's a folder or target
     needsCreateFile &= (items.count() == 1) && (items.first()->folder() || items.first()->target());
@@ -219,6 +225,9 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
 
         //needsRemove if items are limited to non-top-level folders or files that don't belong to targets
         needsRemoveAndRename &= (item->folder() && item->parent()) || (item->file() && !item->parent()->target());
+
+        //needsRemoveTargets if items are limited to file items with target parents
+        needsRemoveTargetFiles &= (item->file() && item->parent()->target());
     }
 
     if ( needsCreateFile ) {
@@ -234,20 +243,20 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
         menuExt.addAction( ContextMenuExtension::FileGroup, action );
     }
     if ( needsBuildItems ) {
-        KAction* action = new KAction( i18n( "Build" ), this );
+        KAction* action = new KAction( i18nc( "@action", "Build" ), this );
         action->setIcon(KIcon("run-build"));
-        connect( action, SIGNAL( triggered() ), this, SLOT(buildItemsFromContextMenu()) );
+        connect( action, SIGNAL(triggered()), this, SLOT(buildItemsFromContextMenu()) );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
-        action = new KAction( i18n( "Install" ), this );
+        action = new KAction( i18nc( "@action", "Install" ), this );
         action->setIcon(KIcon("run-install"));
-        connect( action, SIGNAL( triggered() ), this, SLOT(installItemsFromContextMenu()) );
+        connect( action, SIGNAL(triggered()), this, SLOT(installItemsFromContextMenu()) );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
-        action = new KAction( i18n( "Clean" ), this );
+        action = new KAction( i18nc( "@action", "Clean" ), this );
         action->setIcon(KIcon("run-clean"));
-        connect( action, SIGNAL( triggered() ), this, SLOT(cleanItemsFromContextMenu()) );
+        connect( action, SIGNAL(triggered()), this, SLOT(cleanItemsFromContextMenu()) );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
         action = new KAction( i18n( "Add to Buildset" ), this );
-        connect( action, SIGNAL(triggered() ), this, SLOT(addItemsFromContextMenuToBuildset() ) );
+        connect( action, SIGNAL(triggered()), this, SLOT(addItemsFromContextMenuToBuildset()) );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
     }
     if ( needsCloseProjects ) {
@@ -272,26 +281,13 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
         connect( rename, SIGNAL(triggered()), this, SLOT(renameItemFromContextMenu()) );
         menuExt.addAction( ContextMenuExtension::FileGroup, rename );
     }
-    return menuExt;
-}
-
-
-KDevelop::IProjectBuilder* ProjectManagerViewPlugin::getProjectBuilder( KDevelop::ProjectBaseItem* item )
-{
-    if( !item )
-        return 0;
-    IProject* project = item->project();
-    if (!project)
-        return 0;
-
-    ProjectFolderItem* prjitem = project->projectItem();
-    IPlugin* fmgr = project->managerPlugin();
-    IBuildSystemManager* mgr = fmgr->extension<IBuildSystemManager>();
-    if( mgr )
-    {
-        return mgr->builder( prjitem );
+    if ( needsRemoveTargetFiles ) {
+        KAction* remove = new KAction( i18n( "Remove From Target" ), this );
+        remove->setIcon(KIcon("user-trash"));
+        connect( remove, SIGNAL(triggered()), this, SLOT(removeTargetFilesFromContextMenu()) );
+        menuExt.addAction( ContextMenuExtension::FileGroup, remove );
     }
-    return 0;
+    return menuExt;
 }
 
 void ProjectManagerViewPlugin::closeProjects()
@@ -452,20 +448,25 @@ void ProjectManagerViewPlugin::createFolderFromContextMenu( )
     }
 }
 
-bool projectItemUrlLessThan(KDevelop::ProjectBaseItem* item1, KDevelop::ProjectBaseItem* item2)
-{
-    return item1->url().path() < item2->url().path();
-}
 void ProjectManagerViewPlugin::removeFromContextMenu()
 {
+    removeItems(d->ctxProjectItemList);
+}
+
+void ProjectManagerViewPlugin::removeItems(const QList< ProjectBaseItem* >& items)
+{
+    if (items.isEmpty()) {
+        return;
+    }
+
     //copy the list of selected items and sort it to guarantee parents will come before children
     QMap< IProjectFileManager*, QList<KDevelop::ProjectBaseItem*> > filteredItems;
-    filteredItems[0] += d->ctxProjectItemList;
-    qSort(filteredItems[0].begin(), filteredItems[0].end(), projectItemUrlLessThan);
+    filteredItems[0] = items;
+    qSort(filteredItems[0].begin(), filteredItems[0].end(), ProjectBaseItem::urlLessThan);
 
     KUrl lastFolder;
-    QStringList itemPaths;
 
+    QStringList itemPaths;
     foreach( KDevelop::ProjectBaseItem* item, filteredItems[0] )
     {
         Q_ASSERT(item->folder() || item->file());
@@ -505,11 +506,32 @@ void ProjectManagerViewPlugin::removeFromContextMenu()
     }
 }
 
+void ProjectManagerViewPlugin::removeTargetFilesFromContextMenu()
+{
+    QList<ProjectBaseItem*> items = d->ctxProjectItemList;
+    QMap< IBuildSystemManager*, QList<KDevelop::ProjectFileItem*> > itemsByBuildSystem;
+    foreach(ProjectBaseItem *item, items)
+        itemsByBuildSystem[item->project()->buildSystemManager()].append(item->file());
+
+    QMap< IBuildSystemManager*, QList<KDevelop::ProjectFileItem*> >::iterator it;
+    for (it = itemsByBuildSystem.begin(); it != itemsByBuildSystem.end(); ++it)
+        it.key()->removeFilesFromTargets(it.value());
+}
+
 void ProjectManagerViewPlugin::renameItemFromContextMenu()
 {
-    QWidget* window=ICore::self()->uiController()->activeMainWindow()->window();
+    renameItems(d->ctxProjectItemList);
+}
 
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+void ProjectManagerViewPlugin::renameItems(const QList< ProjectBaseItem* >& items)
+{
+    if (items.isEmpty()) {
+        return;
+    }
+
+    QWidget* window = ICore::self()->uiController()->activeMainWindow()->window();
+
+    foreach( KDevelop::ProjectBaseItem* item, items )
     {
         if ((item->type()!=ProjectBaseItem::BuildFolder
                 && item->type()!=ProjectBaseItem::Folder
@@ -529,8 +551,7 @@ void ProjectManagerViewPlugin::renameItemFromContextMenu()
 
         if (!name.isEmpty() && name != src) {
             ProjectBaseItem::RenameStatus status = item->rename( name );
-            
-            QWidget* window(QApplication::activeWindow());
+
             switch(status) {
                 case ProjectBaseItem::RenameOk:
                     break;
@@ -576,7 +597,7 @@ void ProjectManagerViewPlugin::createFileFromContextMenu( )
             {
                 ProjectFileItem* f=createFile(folder);
                 if(f)
-                    item->project()->buildSystemManager()->addFileToTarget(f, item->target());
+                    item->project()->buildSystemManager()->addFilesToTarget(QList<ProjectFileItem*>() << f, item->target());
             }
         }
     }
